@@ -7,12 +7,15 @@
     clippy::module_name_repetitions,
     clippy::multiple_crate_versions,
     clippy::doc_markdown,
-    non_camel_case_types, dead_code
+    non_camel_case_types,
+    dead_code
 )]
 
 //! FFI bindings for [nethost](https://github.com/dotnet/runtime/blob/main/docs/design/features/host-components.md#components-of-the-hosting).
-//! 
-//! Supports automatically downloading the lastest [nethost](https://github.com/dotnet/runtime/blob/main/docs/design/features/host-components.md#components-of-the-hosting) binary from [NuGet](https://www.nuget.org/) with the `download-nuget` feature.
+//!
+//! Supports automatically downloading the latest version of the [nethost](https://github.com/dotnet/runtime/blob/main/docs/design/features/host-components.md#components-of-the-hosting) library from [NuGet](https://www.nuget.org/packages/Microsoft.NETCore.DotNetHost/) with the `download-nuget` features.
+//! - `download-nuget-system` will download the latest version for the current platform.
+//! - `download-nuget-target` will download the latest version for the target platform.
 //! 
 //! ## Related crates
 //! - [hostfxr-sys](https://crates.io/crates/hostfxr-sys) - bindings for the hostfxr library.
@@ -23,12 +26,12 @@
 //! - [Hosting layer APIs](https://github.com/dotnet/core-setup/blob/master/Documentation/design-docs/hosting-layer-apis.md)
 //! - [Native hosting](https://github.com/dotnet/core-setup/blob/master/Documentation/design-docs/native-hosting.md#runtime-properties)
 //! - [Write a custom .NET Core host to control the .NET runtime from your native code](https://docs.microsoft.com/en-us/dotnet/core/tutorials/netcore-hosting)
-//! 
+//!
 //! ## License
 //! Licensed under the MIT license ([LICENSE](https://github.com/OpenByteDev/nethost-sys/blob/master/LICENSE) or <http://opensource.org/licenses/MIT>)
 
+use core::{mem, ptr};
 use coreclr_hosting_shared::{char_t, size_t};
-use core::{ptr, mem};
 
 // for some reason we need the link attribute here for unix, but the rustc argument in build.rs for windows.
 // #[cfg_attr(windows, link(name = "libnethost"))]
@@ -56,7 +59,7 @@ extern "system" {
     ///
     /// # Return value
     ///  * `0` on success, otherwise failure
-    ///  * `0x80008098` - `buffer` is too small (`HostApiBufferTooSmall`)
+    ///  * `0x80008098` - `buffer` is too small ([`HostApiBufferTooSmall`](https://docs.rs/coreclr-hosting-shared/0.1.2/coreclr_hosting_shared/enum.StatusCode.html#variant.HostApiBufferTooSmall)
     ///
     /// # Remarks
     /// The full search for the hostfxr library is done on every call. To minimize the need
